==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/ContinuousModeBackupPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The object representing continuous mode backup policy.
 * @property continuousModeProperties Configuration values for continuous mode backup
 * @property migrationState The object representing the state of the migration between the backup policies.
 * @property type Describes the mode of backups.
 * Expected value is 'Continuous'.
 */
public data class ContinuousModeBackupPolicyArgs(
    public val continuousModeProperties: Output<ContinuousModePropertiesArgs>? = null,
    public val migrationState: Output<BackupPolicyMigrationStateArgs>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs =
        com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs.builder()
            .continuousModeProperties(
                continuousModeProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .migrationState(migrationState?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContinuousModeBackupPolicyArgs].
 */
@PulumiTagMarker
public class ContinuousModeBackupPolicyArgsBuilder internal constructor() {
    private var continuousModeProperties: Output<ContinuousModePropertiesArgs>? = null

    private var migrationState: Output<BackupPolicyMigrationStateArgs>? = null

    private var type: Output<String>? = null

    /**
     * @param value Configuration values for continuous mode backup
     */
    @JvmName("lnykswmmwmuxxrkl")
    public suspend fun continuousModeProperties(`value`: Output<ContinuousModePropertiesArgs>) {
        this.continuousModeProperties = value
    }

    /**
     * @param value The object representing the state of the migration between the backup policies.
     */
    @JvmName("bdmlukddechmsbyd")
    public suspend fun migrationState(`value`: Output<BackupPolicyMigrationStateArgs>) {
        this.migrationState = value
    }

    /**
     * @param value Describes the mode of backups.
     * Expected value is 'Continuous'.
     */
    @JvmName("hfcvcjosregoackk")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Configuration values for continuous mode backup
     */
    @JvmName("balnrpmhvqpbmeje")
    public suspend fun continuousModeProperties(`value`: ContinuousModePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.continuousModeProperties = mapped
    }

    /**
     * @param argument Configuration values for continuous mode backup
     */
    @JvmName("omyrhoxmdlqgpolj")
    public suspend
    fun continuousModeProperties(argument: suspend ContinuousModePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ContinuousModePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.continuousModeProperties = mapped
    }

    /**
     * @param value The object representing the state of the migration between the backup policies.
     */
    @JvmName("asdvnkkfhnfhfiir")
    public suspend fun migrationState(`value`: BackupPolicyMigrationStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.migrationState = mapped
    }

    /**
     * @param argument The object representing the state of the migration between the backup policies.
     */
    @JvmName("xgdgamlwbuhuqeif")
    public suspend
    fun migrationState(argument: suspend BackupPolicyMigrationStateArgsBuilder.() -> Unit) {
        val toBeMapped = BackupPolicyMigrationStateArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.migrationState = mapped
    }

    /**
     * @param value Describes the mode of backups.
     * Expected value is 'Continuous'.
     */
    @JvmName("fyedxkorxovnyohl")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ContinuousModeBackupPolicyArgs = ContinuousModeBackupPolicyArgs(
        continuousModeProperties = continuousModeProperties,
        migrationState = migrationState,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/ContinuousModeBackupPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The object representing continuous mode backup policy.
 * @property continuousModeProperties Configuration values for continuous mode backup
 * @property migrationState The object representing the state of the migration between the backup policies.
 * @property type Describes the mode of backups.
 * Expected value is 'Continuous'.
 */
public data class ContinuousModeBackupPolicyArgs(
    public val continuousModeProperties: Output<ContinuousModePropertiesArgs>? = null,
    public val migrationState: Output<BackupPolicyMigrationStateArgs>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs =
        com.pulumi.azurenative.documentdb.inputs.ContinuousModeBackupPolicyArgs.builder()
            .continuousModeProperties(
                continuousModeProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .migrationState(migrationState?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContinuousModeBackupPolicyArgs].
 */
@PulumiTagMarker
public class ContinuousModeBackupPolicyArgsBuilder internal constructor() {
    private var continuousModeProperties: Output<ContinuousModePropertiesArgs>? = null

    private var migrationState: Output<BackupPolicyMigrationStateArgs>? = null

    private var type: Output<String>? = null

    /**
     * @param value Configuration values for continuous mode backup
     */
    @JvmName("ujinndvgvwdqjwap")
    public suspend fun continuousModeProperties(`value`: Output<ContinuousModePropertiesArgs>) {
        this.continuousModeProperties = value
    }

    /**
     * @param value The object representing the state of the migration between the backup policies.
     */
    @JvmName("aopmvmghmviqmiea")
    public suspend fun migrationState(`value`: Output<BackupPolicyMigrationStateArgs>) {
        this.migrationState = value
    }

    /**
     * @param value Describes the mode of backups.
     * Expected value is 'Continuous'.
     */
    @JvmName("brqlwpvhljdfrpgo")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Configuration values for continuous mode backup
     */
    @JvmName("ooulpaydvpjpvkif")
    public suspend fun continuousModeProperties(`value`: ContinuousModePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.continuousModeProperties = mapped
    }

    /**
     * @param argument Configuration values for continuous mode backup
     */
    @JvmName("yibcxphcofussise")
    public suspend
    fun continuousModeProperties(argument: suspend ContinuousModePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ContinuousModePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.continuousModeProperties = mapped
    }

    /**
     * @param value The object representing the state of the migration between the backup policies.
     */
    @JvmName("xtgqfndeuvhtyeoe")
    public suspend fun migrationState(`value`: BackupPolicyMigrationStateArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.migrationState = mapped
    }

    /**
     * @param argument The object representing the state of the migration between the backup policies.
     */
    @JvmName("sxytlfulrmbvvnnm")
    public suspend
    fun migrationState(argument: suspend BackupPolicyMigrationStateArgsBuilder.() -> Unit) {
        val toBeMapped = BackupPolicyMigrationStateArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.migrationState = mapped
    }

    /**
     * @param value Describes the mode of backups.
     * Expected value is 'Continuous'.
     */
    @JvmName("njeyxoqmddyxpupy")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ContinuousModeBackupPolicyArgs = ContinuousModeBackupPolicyArgs(
        continuousModeProperties = continuousModeProperties,
        migrationState = migrationState,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
